On 25/8/26 21:09, Marc-André Lureau wrote:
Thread through the current *hmp monitor, a non-NULL pointer is
guaranteed to be a valid HMP monitor. Adjust doc comments.
No behavioral change.
Signed-off-by: Marc-André Lureau <[email protected]>
---
util/error-report.c | 69 ++++++++++++++++++++++-------------------------------
1 file changed, 29 insertions(+), 40 deletions(-)
diff --git a/util/error-report.c b/util/error-report.c
index aaa15bc79827..aa278de6646a 100644
--- a/util/error-report.c
+++ b/util/error-report.c
@@ -30,34 +30,29 @@ bool error_with_guestname;
const char *error_guest_name;
/*
* Print to the current human monitor if we have one, else to stderr.
*/
static int G_GNUC_PRINTF(2, 0)
-error_vprintf_mon(Monitor *cur_mon, const char *fmt, va_list ap)
+error_vprintf_mon(MonitorHMP *hmp, const char *fmt, va_list ap)
If you ever respin, error_vprintf_hmp() would be a better name.
Reviewed-by: Philippe Mathieu-Daudé <[email protected]>
@@ -30,34 +30,29 @@ bool error_with_guestname;
const char *error_guest_name;
/*
- * Print to the current human monitor if we have one, else to stderr.
+ * Print to the @hmp monitor, else to stderr.
*/
static int G_GNUC_PRINTF(2, 0)